<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>S:</name>
    <message>
        <location filename="customtype.cpp" line="93"/>
        <source></source>
        <comment>the device ID of the current device, e.g. &quot;battery0&quot;</comment>
        <translation></translation>
    </message>
</context>
<context>
    <name>TitleWidget</name>
    <message>
        <source>help</source>
        <translation type="obsolete">help</translation>
    </message>
    <message>
        <location filename="titlewidget.cpp" line="79"/>
        <source>Power Information</source>
        <oldsource>Power Statistics-device information</oldsource>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UkpmWidget</name>
    <message>
        <location filename="ukpm-widget.cpp" line="103"/>
        <source>AC adapter</source>
        <translation>AC adapter</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="107"/>
        <source>Laptop battery</source>
        <translation>Laptop battery</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="111"/>
        <source>UPS</source>
        <translation>UPS</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="115"/>
        <source>Monitor</source>
        <translation>Monitor</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="119"/>
        <source>Mouse</source>
        <translation>Mouse</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="123"/>
        <source>Keyboard</source>
        <translation>Keyboard</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="127"/>
        <source>PDA</source>
        <translation>PDA</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="131"/>
        <source>Cell phone</source>
        <translation>Cell phone</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="135"/>
        <source>Media player</source>
        <translation>Media player</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="139"/>
        <source>Tablet</source>
        <translation>Tablet</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="143"/>
        <source>Computer</source>
        <translation>Computer</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="201"/>
        <location filename="ukpm-widget.cpp" line="307"/>
        <location filename="ukpm-widget.cpp" line="1928"/>
        <source>Charging</source>
        <translation>Charging</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="204"/>
        <location filename="ukpm-widget.cpp" line="310"/>
        <location filename="ukpm-widget.cpp" line="1931"/>
        <source>Discharging</source>
        <translation>Discharging</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="207"/>
        <location filename="ukpm-widget.cpp" line="313"/>
        <location filename="ukpm-widget.cpp" line="1934"/>
        <source>Empty</source>
        <translation>Empty</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="210"/>
        <location filename="ukpm-widget.cpp" line="316"/>
        <location filename="ukpm-widget.cpp" line="1937"/>
        <source>Charged</source>
        <translation>Charged</translation>
    </message>
    <message>
        <source>Notebook battery</source>
        <translation type="vanished">Notebook battery</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="vanished">Yes</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="vanished">No</translation>
    </message>
    <message>
        <source>Detail</source>
        <translation type="vanished">Detail</translation>
    </message>
    <message>
        <source>attribute</source>
        <translation type="vanished">attribute</translation>
    </message>
    <message>
        <source>value</source>
        <translation type="vanished">value</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="416"/>
        <source>Device</source>
        <translation>Device</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="418"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <source>PowerSupply</source>
        <translation type="vanished">PowerSupply</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="503"/>
        <source>Online</source>
        <translation>Online</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="421"/>
        <source>Vendor</source>
        <translation>Vendor</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="423"/>
        <source>Model</source>
        <translation>Model</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation type="vanished">Refresh</translation>
    </message>
    <message>
        <source>IsPresent</source>
        <translation type="vanished">IsPresent</translation>
    </message>
    <message>
        <source>IsRechargeable</source>
        <translation type="vanished">IsRechargeable</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="457"/>
        <source>State</source>
        <translation>State</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="462"/>
        <source>Energy</source>
        <translation>Energy</translation>
    </message>
    <message>
        <source>EnergyFull</source>
        <translation type="vanished">EnergyFull</translation>
    </message>
    <message>
        <source>EnergyFullDesign</source>
        <translation type="vanished">EnergyFullDesign</translation>
    </message>
    <message>
        <source>EnergyRate</source>
        <translation type="vanished">EnergyRate</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="476"/>
        <source>Voltage</source>
        <translation>Voltage</translation>
    </message>
    <message>
        <source>TimeToFull</source>
        <translation type="vanished">TimeToFull</translation>
    </message>
    <message>
        <source>TimeToEmpty</source>
        <translation type="vanished">TimeToEmpty</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="494"/>
        <source>Percentage</source>
        <translation>Percentage</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="499"/>
        <source>Capacity</source>
        <translation>Capacity</translation>
    </message>
    <message>
        <source>Power Statistics</source>
        <translation type="vanished">Power Statistics</translation>
    </message>
    <message>
        <source>help</source>
        <translation type="vanished">help</translation>
    </message>
    <message>
        <source>exit</source>
        <translation type="vanished">exit</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation type="vanished">Statistics</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1210"/>
        <location filename="ukpm-widget.cpp" line="1373"/>
        <source>graphic type:</source>
        <translation>graphic type:</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1213"/>
        <source>charge</source>
        <translation>charge</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1213"/>
        <source>charge-accurency</source>
        <translation>charge-accurency</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1213"/>
        <source>discharge</source>
        <translation>discharge</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1213"/>
        <source>discharge-accurency</source>
        <translation>discharge-accurency</translation>
    </message>
    <message>
        <source>spline</source>
        <translation type="vanished">spline</translation>
    </message>
    <message>
        <source>show datapoint</source>
        <translation type="vanished">show datapoint</translation>
    </message>
    <message>
        <source>no data to show.</source>
        <translation type="vanished">no data to show.</translation>
    </message>
    <message>
        <source>History</source>
        <translation type="vanished">History</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1375"/>
        <source>time span:</source>
        <translation>time span:</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1380"/>
        <source>rate</source>
        <translation>rate</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1380"/>
        <source>energy</source>
        <translation>energy</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1380"/>
        <source>charge-time</source>
        <translation>charge-time</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1380"/>
        <source>discharge-time</source>
        <translation>discharge-time</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1383"/>
        <source>ten minutes</source>
        <translation>ten minutes</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1383"/>
        <source>two hours</source>
        <translation>two hours</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1383"/>
        <source>six hours</source>
        <translation>six hours</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1383"/>
        <source>one day</source>
        <translation>one day</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1383"/>
        <source>one week</source>
        <translation>one week</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1439"/>
        <source>elapsed time</source>
        <translation>elapsed time</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="711"/>
        <location filename="ukpm-widget.cpp" line="800"/>
        <source>adjust factor</source>
        <translation>adjust factor</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="213"/>
        <location filename="ukpm-widget.cpp" line="319"/>
        <location filename="ukpm-widget.cpp" line="1940"/>
        <source>PendingCharge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="216"/>
        <location filename="ukpm-widget.cpp" line="322"/>
        <location filename="ukpm-widget.cpp" line="1943"/>
        <source>PendingDischarge</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="413"/>
        <source>Attribute</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="413"/>
        <source>Value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="425"/>
        <source>Serial number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="427"/>
        <source>Supply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="436"/>
        <source>Refreshed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="444"/>
        <source>Present</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="450"/>
        <source>Rechargeable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="464"/>
        <source>Energy when full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="465"/>
        <source>Energy (design)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="481"/>
        <source>Time to full</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="485"/>
        <source>Time to empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="521"/>
        <source>history</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="532"/>
        <source>statistics</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="714"/>
        <location filename="ukpm-widget.cpp" line="757"/>
        <location filename="ukpm-widget.cpp" line="803"/>
        <location filename="ukpm-widget.cpp" line="846"/>
        <source>battery power</source>
        <translation>battery power</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="754"/>
        <location filename="ukpm-widget.cpp" line="840"/>
        <source>Predict Accurency</source>
        <translation>Predict Accurency</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1219"/>
        <location filename="ukpm-widget.cpp" line="1392"/>
        <source>show line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1220"/>
        <location filename="ukpm-widget.cpp" line="1393"/>
        <source>show data points</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1345"/>
        <source>detail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="470"/>
        <location filename="ukpm-widget.cpp" line="978"/>
        <source>Rate</source>
        <translation>Rate</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="995"/>
        <source>Charge</source>
        <translation>Charge</translation>
    </message>
    <message>
        <location filename="ukpm-widget.cpp" line="1016"/>
        <location filename="ukpm-widget.cpp" line="1059"/>
        <source>Predict Time</source>
        <translation>Predict Time</translation>
    </message>
    <message>
        <location filename="ukpm-widget.h" line="124"/>
        <source>s</source>
        <translation>s</translation>
    </message>
    <message>
        <location filename="ukpm-widget.h" line="126"/>
        <source>m</source>
        <translation>m</translation>
    </message>
    <message>
        <location filename="ukpm-widget.h" line="128"/>
        <source>h</source>
        <translation>h</translation>
    </message>
    <message>
        <location filename="ukpm-widget.h" line="133"/>
        <source>yes</source>
        <translation></translation>
    </message>
    <message>
        <location filename="ukpm-widget.h" line="133"/>
        <source>no</source>
        <translation></translation>
    </message>
    <message>
        <source>line-power</source>
        <translation type="vanished">line-power</translation>
    </message>
    <message>
        <source>battery</source>
        <translation type="vanished">battery</translation>
    </message>
    <message>
        <source>ups</source>
        <translation type="vanished">ups</translation>
    </message>
    <message>
        <source>monitor</source>
        <translation type="vanished">monitor</translation>
    </message>
    <message>
        <source>mouse</source>
        <translation type="vanished">mouse</translation>
    </message>
    <message>
        <source>keyboard</source>
        <translation type="vanished">keyboard</translation>
    </message>
    <message>
        <source>pda</source>
        <translation type="vanished">pda</translation>
    </message>
    <message>
        <source>phone</source>
        <translation type="vanished">phone</translation>
    </message>
    <message>
        <source>media-player</source>
        <translation type="vanished">media-player</translation>
    </message>
    <message>
        <source>tablet</source>
        <translation type="vanished">tablet</translation>
    </message>
    <message>
        <source>computer</source>
        <translation type="vanished">computer</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="vanished">unknown</translation>
    </message>
</context>
</TS>
